==> kubernetes-model-admissionregistration-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SubjectAccessReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SubjectAccessReviewStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatusFluent<A>{
  public SubjectAccessReviewStatusFluentImpl() {
  }
  public SubjectAccessReviewStatusFluentImpl(io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatus instance) {
    this.withAllowed(instance.getAllowed()); 
    this.withDenied(instance.getDenied()); 
    this.withEvaluationError(instance.getEvaluationError()); 
    this.withReason(instance.getReason()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean allowed;
  private java.lang.Boolean denied;
  private java.lang.String evaluationError;
  private java.lang.String reason;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAllowed() {
    return this.allowed;
  }
  public A withAllowed(java.lang.Boolean allowed) {
    this.allowed=allowed; return (A) this;
  }
  public java.lang.Boolean hasAllowed() {
    return this.allowed != null;
  }
  public java.lang.Boolean getDenied() {
    return this.denied;
  }
  public A withDenied(java.lang.Boolean denied) {
    this.denied=denied; return (A) this;
  }
  public java.lang.Boolean hasDenied() {
    return this.denied != null;
  }
  public java.lang.String getEvaluationError() {
    return this.evaluationError;
  }
  public A withEvaluationError(java.lang.String evaluationError) {
    this.evaluationError=evaluationError; return (A) this;
  }
  public java.lang.Boolean hasEvaluationError() {
    return this.evaluationError != null;
  }
  
  /**
   * Method is deprecated. use withEvaluationError instead.
   */
  @java.lang.Deprecated
  public A withNewEvaluationError(java.lang.String arg0) {
    return (A)withEvaluationError(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubjectAccessReviewStatusFluentImpl that = (SubjectAccessReviewStatusFluentImpl) o;
    if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
    if (denied != null ? !denied.equals(that.denied) :that.denied != null) return false;
    if (evaluationError != null ? !evaluationError.equals(that.evaluationError) :that.evaluationError != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowed,  denied,  evaluationError,  reason,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SubjectAccessReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SubjectAccessReviewStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatusFluent<A>{
  public SubjectAccessReviewStatusFluentImpl() {
  }
  public SubjectAccessReviewStatusFluentImpl(io.fabric8.kubernetes.api.model.authorization.v1.SubjectAccessReviewStatus instance) {
    this.withAllowed(instance.getAllowed()); 
    this.withDenied(instance.getDenied()); 
    this.withEvaluationError(instance.getEvaluationError()); 
    this.withReason(instance.getReason()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean allowed;
  private java.lang.Boolean denied;
  private java.lang.String evaluationError;
  private java.lang.String reason;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAllowed() {
    return this.allowed;
  }
  public A withAllowed(java.lang.Boolean allowed) {
    this.allowed=allowed; return (A) this;
  }
  public java.lang.Boolean hasAllowed() {
    return this.allowed != null;
  }
  public java.lang.Boolean getDenied() {
    return this.denied;
  }
  public A withDenied(java.lang.Boolean denied) {
    this.denied=denied; return (A) this;
  }
  public java.lang.Boolean hasDenied() {
    return this.denied != null;
  }
  public java.lang.String getEvaluationError() {
    return this.evaluationError;
  }
  public A withEvaluationError(java.lang.String evaluationError) {
    this.evaluationError=evaluationError; return (A) this;
  }
  public java.lang.Boolean hasEvaluationError() {
    return this.evaluationError != null;
  }
  
  /**
   * Method is deprecated. use withEvaluationError instead.
   */
  @java.lang.Deprecated
  public A withNewEvaluationError(java.lang.String arg0) {
    return (A)withEvaluationError(new String(arg0));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubjectAccessReviewStatusFluentImpl that = (SubjectAccessReviewStatusFluentImpl) o;
    if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
    if (denied != null ? !denied.equals(that.denied) :that.denied != null) return false;
    if (evaluationError != null ? !evaluationError.equals(that.evaluationError) :that.evaluationError != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowed,  denied,  evaluationError,  reason,  additionalProperties,  super.hashCode());
  }
  
}
